import { Language } from './languages.js';
import { HarRequest } from '@readme/httpsnippet';
import { ClientPlugin } from '@readme/httpsnippet/targets';
import { DataForHAR, AuthForHAR } from '@readme/oas-to-har/lib/types';
import Oas from 'oas';
import { Operation } from 'oas/operation';

declare function oasToSnippet(oas: Oas, operation: Operation, values: DataForHAR, auth: AuthForHAR, lang: Language, opts?: {
    /**
     * If you already have a HAR and you just want to generate a code snippet for it then you should
     * supply that HAR to this option.
     *
     */
    harOverride?: HarRequest;
    /**
     * Various options that are required for generating `[node, api]` code snippets.
     *
     * @see {@link https://npm.im/httpsnippet-client-api}
     */
    openapi?: {
        /**
         * The ReadMe API Registry identifier for this OpenAPI definition.
         *
         * @example @developers/v2.0#17273l2glm9fq4l5
         */
        registryIdentifier?: string;
        /**
         * This is the primary variable name that will be used in the code snippet. If supplied this
         * will take precedence over any supplied `registryIdentifier`.
         *
         * @example developers
         */
        variableName?: string;
    };
    /**
     * `httpsnippet` plugins to extend snippet generation to.
     *
     */
    plugins?: ClientPlugin<any>[];
}): {
    /**
     * The resulting code snippet. Returns `false` if a snippet could not be generated.
     *
     * @example ```sh
     * curl --request DELETE --url http://petstore.swagger.io/v2/pet/petId
     * ```
     */
    code: string | false;
    /**
     * The programming language (used for syntax highlighting).
     * Returns `false` if a language could not be determined.
     *
     * @example shell
     */
    highlightMode: string | false;
    /**
     * Installation instructions for using the snippet.
     * Returns `false` if the snippet does not have an installation step.
     *
     * @example ```sh
     * npm install node-fetch@2 --save
     * ```
     */
    install: string | false;
};

export { oasToSnippet as default };
