import { TargetId, ClientId, ClientPlugin } from '@readme/httpsnippet/targets';

type Language = keyof typeof DEFAULT_LANGUAGES | [keyof typeof DEFAULT_LANGUAGES, ClientId];
interface LanguageConfig {
    highlight: string;
    httpsnippet: {
        default: ClientId;
        lang: TargetId;
        targets: Record<ClientId, {
            install?: string;
            name: string;
            opts?: Record<string, unknown>;
        }>;
    };
}
type SupportedTargets = Exclude<TargetId, 'objc'> | 'cplusplus' | 'objectivec';
type SupportedLanguages = Record<SupportedTargets, LanguageConfig>;
declare const DEFAULT_LANGUAGES: SupportedLanguages;
/**
 * Retrieve all supported supported languages by this library. You can also optionally supply an
 * array of `httpsnippet` plugins to extend this list.
 *
 */
declare function getSupportedLanguages({ plugins, }?: {
    plugins?: ClientPlugin<any>[];
}): SupportedLanguages;
declare function getLanguageConfig(languages: SupportedLanguages, lang: Language): {
    config: LanguageConfig | undefined;
    language: TargetId | undefined;
    target: ClientId | undefined;
};
declare function getClientInstallationInstructions(languages: SupportedLanguages, lang: Language, 
/**
 * For `api` snippet generation we need supply a ReadMe API Registry identifier that'll be used
 * to retrieve the OpenAPI definition to generate their SDK through the `npx api install` command.
 * These users won't be installing the `api` package itself to run the snippets we generate for
 * them.
 *
 * @example @developers/v2.0#17273l2glm9fq4l5
 */
registryIdentifier?: string): string | undefined;

export { type Language, type LanguageConfig, type SupportedLanguages, type SupportedTargets, getClientInstallationInstructions, getLanguageConfig, getSupportedLanguages };
